function [ classification ] = BlockClassification(size_tri, Gx, Gy, GxGy, indices, cutoff_percent, cutoff_stvalue, directions )
%BLOCKCLASSIFICATION Classifies a block based on contained texture
%
%   Input parameters:
%       size_tri       : Size of current image block.
%       Gx             : Horizontal partial derivatives.
%       Gy             : Vertical partial derivatives.
%       GxGy           : Product of partial derivatives.
%       indices        : Indices of image block in the image.
%       cutoff_percent : Threshold for the complex coherence.
%       cutoff_stvalue : Threshold for the texture content.
%       directions     : Prototype vectors for dominant blocks.
%   Output parameters: 
%       classification : Class and group of the image block.


%Compute eigenvalues and largest eigenvector of structure tensor
[stev, stevec] = ComputeStructureTensor(size_tri, Gx, Gy, GxGy, indices);

max_stev = max(stev);
min_stev = min(stev);

%Select case based on structure tensor
if ((max_stev-min_stev)/(max_stev+min_stev))^2 < cutoff_percent && max_stev > cutoff_stvalue %complex case
    classification = 'complex'; 
elseif max_stev > cutoff_stvalue %dominant case
    V = repmat(stevec',4,1);
   [~,aux] = min(abs(dot(V,directions,2)));
   if aux == 1
       classification = 'horizontal'; %horizontal textures
   elseif aux == 2
       classification = 'll_tr'; %diagonal textures, lower left to top right
   elseif aux == 3
       classification = 'vertical'; %vertical textures
   else
       classification = 'lr_tl'; %diagonal textures, lower right to top left
   end
else %smooth case
    classification = 'smooth';
end       
end

