function [ Gx, Gy ] = ComputeGradientMatrix( im, im_tri, resolution )
%ComputeGradientMatrix Computes gradient matrix of whole image
%
%   Input parameters:
%       im          : Texture image.
%       im_tri      : Triangulation matrix.
%       resolution  : Resolution of original image.
%   Output parameters:
%       Gx          : Horizontal partial derivatives.
%       GY          : Vertical partial derivatives.


%Initialisation
Gx = zeros(resolution);
Gy = Gx;

for i = 1:resolution(1)
    for j = 1:resolution(2)
        
        cur = im_tri(i,j);  %current triangle
        
        %Gx        
        %Left
        if j~=1 && im_tri(i,j-1) == cur
            Gx(i,j) = im(i,j) - im(i,j-1);
        end
        
        %Right
        if j~= resolution(2) && im_tri(i,j+1) == cur
            Gx(i,j) = Gx(i,j) + im(i,j+1)-im(i,j);
        end
        
        %Gy        
        %Top
        if i~=1 && im_tri(i-1,j) == cur
            Gy(i,j) = im(i,j) - im(i-1,j);
        end
        
        %Bottom
        if i~= resolution(1) && im_tri(i+1,j) == cur
            Gy(i,j) = Gy(i,j) + im(i+1,j)-im(i,j);
        end
    end
end
end

