function [ w_opt ] = ComputeOptimizedWeightVector(im_signal, incidence_matrix, L_l) 
%ComputeOptimizedWeightVector Optimizes edge weight vector
%
%   Input parameters: 
%       im_signal        : Signal on image block.
%       incidence_matrix : Incidence matrix of underlying graph.
%       L_l              : Line graphof underlying graph.
%   Output parameters:
%       w_opt            : Optimized edge weight vector.

%Set optimization options
options = optimoptions(@fmincon,'StepTolerance', 1e-6, 'Display', 'off');
%Set parameters
alpha = 10;
beta = 0.01;

%Compute difference vector
d = diag(incidence_matrix*(im_signal * im_signal') * incidence_matrix')';
vec_1 = ones(size(incidence_matrix,1),1);

%Define objective function
fun = @(w) d*w +length(vec_1)*alpha*norm(L_l.U'*w,1)-length(vec_1)*beta*vec_1'*log(w);

%Set initial vector
w0 = exp(-d/(0.25*max(d)))';

w_opt = fmincon(fun,w0,[],[],[],[],[],vec_1,[],options);
end

