function [ quantization_vector ] = ComputeQuantizationVector( L , size_vector )
%COMPUTEQUANTIZATIONVECTOR Computes quantization vector for smooth image blocks.
% 
%   Input parameters:
%       L                   : Graph Laplacian of underlying graph. 
%       size_vector         : Size of image block.
%   Output parameters:
%       quantization_vector : Adapted quantization vector.

rel_frequencies = zeros(size_vector,1);

if max(max(L.L)) == 0
    quantization_vector = 16*ones(size_vector,1);
else    
    %Standard quantization vector
    x = linspace(0,1,15);
    y = 2.5*[16 14 13 15 19 28 37 55 64 83 103 117 117 111 90];

    %Compute relative frequency of each elemental frequency
    for i = 1:size_vector
        rel_frequencies(i) = (L.U(:,i))' * L.L *L.U(:,i);
    end
    rel_frequencies = abs(rel_frequencies)/max(rel_frequencies);

    %Compute Quantization Vector
    quantization_vector = interp1(x,y,rel_frequencies);
end
end

