function [ stev, stevec ] = ComputeStructureTensor(size_tri, Gx, Gy, GxGy, indices)
%ComputeStructureTensor Computes structure tensor of image block
%   Input parameters:
%       size_tri    : Size of current image block.
%       Gx          : Horizontal partial derivatives.
%       Gy          : Vertical partial derivatives.
%       indices     : Indices of image block in the image.
%   Output parameters:
%       stev        : Eigenvalues of the structure tensor.
%       stevec      : Largest eigenvector of the structure tensor.

%Compute structure tensor
st = 1/size_tri * [sum(Gx(indices)) sum(GxGy(indices)) ; ...
                      sum(GxGy(indices)) sum(Gy(indices))];

%Compute eigenvalues and largest eigenvector               
[V,D] = eig(st);   
stev = diag(D);
stevec = V(:,1);
end

