function [ incidence_matrix ] = CreateIncidenceMatrix( indices, resolution, size_signal, graph_mode)
%CreateIncidenceMatrix Create incidence matrix of underlying graph
%
%   Input parameters:
%       indices             : Indices of image block in the image.
%       resolution          : Resolution of original image.
%       size_signal         : Size of current image block.
%       graph_mode          : 4- or 8-connectivity graph.
%   Output parameters:
%       incidence_matrix    : Incidence matrix of underlying graph.


%Create Smooth weight matrix
W = CreateSmoothWeightMatrix(indices,resolution,graph_mode);
    
%Indices where W~=0 
[m,n] = find(W);

%Indices in upper Triangular Matrix where W~=0
% -> every edge once and ordered
par = n-m;
ind = horzcat(m(par>0),n(par>0));

%Changes sorting
ind = sortrows(ind, 'ascend');

%Initialize incidence matrix of G
incidence_matrix = zeros(length(ind),size_signal);

for i = 1:size(ind,1)    
    %set incidence matrix
    incidence_matrix(i,ind(i,1)) = -1;
    incidence_matrix(i,ind(i,2)) = 1;
end
end

