function [ W ] = CreateSmoothWeightMatrix(indices, resolution, graph_mode)
%CreateSmoothWeightMatrix Creates nonadaptive, smooth weight matrix
%
%   Input parameters:
%       indices         : Indices of image block in the image.
%       resolution      : Resolution of original image.
%       graph_mode      : 4- or 8-connectivity graph.
%   Ouput parameters:
%       W               : Smooth weight matrix.

%Initialise matrix
W = zeros(length(indices));

res_horz = resolution(2);
res_vert = resolution(1);

%Create smooth weight matrix
for j = 1:length(indices)
    index = indices(j);

    %Check boundaries
    if index <= res_vert
        left_of_image = true;
    else
        left_of_image = false;
    end
    if index > res_vert*(res_horz-1)
        right_of_image = true;
    else
        right_of_image = false;
    end
    if mod(index,res_vert) == 1
        top_of_image = true;
    else
        top_of_image = false;
    end
    if mod(index,res_vert) == 0
        bottom_of_image = true;
    else
        bottom_of_image= false;
    end

    % pixel above
    if ~top_of_image && ismember(index-1,indices)
        W(j,j-1) = 1;
    end

    % pixel below
    if ~bottom_of_image && ismember(index+1,indices)
        W(j,j+1) = 1;
    end

    % pixel to the right
    if ~right_of_image && ismember(index+res_vert,indices)
        W(j,indices == index+res_vert) = 1;
    end

    % pixel to the left
    if ~left_of_image && ismember(index-res_vert,indices)
        W(j,indices == index-res_vert) = 1;
    end 

    if graph_mode == 8
        % pixel top-left
        if ~top_of_image && ~left_of_image && ismember(index-res_vert-1,indices)
            W(j,indices == index-res_vert-1) = 1;
        end

        % pixel top-right
        if ~top_of_image && ~right_of_image && ismember(index+res_vert-1,indices)
            W(j,indices == index+res_vert-1) = 1;
        end

        % pixel bottom-left
        if ~bottom_of_image && ~left_of_image && ismember(index-res_vert+1,indices)
            W(j,indices == index-res_vert+1) = 1;
        end

        % pixel bottom-right
        if ~bottom_of_image && ~right_of_image && ismember(index+res_vert+1,indices)
            W(j,indices == index+res_vert+1) = 1;
        end
    end
end
end

