function [ im_tri, size_tri ] = CreateTriangleMatrix( source,resolution )
%CreateTriangleMatrix Creates a matrix that lists triangle numbers
%
%   Input parameters:
%       source      : Significant pixels as .inside file.
%       resolution  : Resolution of original image.
%   Output parameters:
%       im_tri      : Triangulation matrix.
%       size_tri    : Size of all image blocks.

%Matrix containing triangle associated with every pixel
im_tri = zeros(resolution); 

%Load point data from .inside file
points = importdata(source);

%Reshape point data
points(1:3) = [];
points = reshape(points,3,[])';

%Delete superfluous data column
points(:,3) = [];

%Reshape triangulation to coincide with matrix
points = points+1; 
points(:,[1,2]) = points(:,[2,1]);

%Create Delaunay triangulation over point set
TR = delaunayTriangulation(points); 

%Amount of triangles
size_tri = zeros(size(TR.ConnectivityList,1),1);  

%Compute triangle matrix 
for i = 1:resolution
    for j = 1:resolution
        par = pointLocation(TR,[i,j]); 
        im_tri(i,j) = par;
        size_tri(par) = size_tri(par)+1;
    end
end
end

