function [ SSIM_local ] = LocalSSIM( im, im_at)
%LocalSSIM Estimates influence of an image block on SSIM value
%
%   Input parameters:
%       im          : Original image.    
%       im_at:      : AT reconstruction.
%   Ouput parameters:
%       SSIM_local  : Local SSIM value.

%Standard choices for constants
C1 = (0.01*255)^2;
C2 = 9*C1;

len = length(im);

%Mean values
mu_im = sum(im)/len;
mu_at = sum(im_at)/len;

if len ~= 1
    %Variances
    sigma_im = sqrt((sum((im-mu_im).^2)/(len-1)));
    sigma_at = sqrt((sum((im_at-mu_at).^2)/(len-1)));
    
    %Correlation
    sigma = sum((im-mu_im).*(im_at-mu_at))/(len-1);
    
    %Local SSIM
    SSIM_at = (2*mu_im*mu_at + C1)*(2*sigma + C2)/((mu_im^2 + mu_at^2 + C1) * (sigma_im^2 + sigma_at^2 + C2));    
else
    SSIM_at = (2*mu_im*mu_at+C1) / (mu_im^2+mu_at^2+C1);
end

%Weighted local SSIM
SSIM_local = (1-SSIM_at)*len;

end

